@@ -1,6 +1,7 @@
 package Template::Mustache::Token::Section;
 our $AUTHORITY = 'cpan:YANICK';
-$Template::Mustache::Token::Section::VERSION = '1.0.4';
+# ABSTRACT: Object representing a Section block
+$Template::Mustache::Token::Section::VERSION = '1.1.0';
 use Moo;
 
 use MooseX::MungeHas { has_ro => [ 'is_ro' ] };
@@ -58,11 +59,11 @@ __END__
 
 =head1 NAME
 
-Template::Mustache::Token::Section
+Template::Mustache::Token::Section - Object representing a Section block
 
 =head1 VERSION
 
-version 1.0.4
+version 1.1.0
 
 =head1 AUTHORS
 
